@@ -46,13 +46,17 @@ def arg_parser():
     version_name = args.number
     upload_file_path = args.path
 
+    # print('radarType: ', radarType)
+    # print('version_name: ', version_name)
+    # print('upload_file_path: ', upload_file_path)
+
     if args.check:
         # check if all the prerequisites are met
         logger.log(message="All prerequisites met.", log_level="info", to_file=True, to_terminal=True)
         exit(0)
     elif args.upload:
         if radarType is None or version_name is None or upload_file_path is None:
-            print('Please provide all the arguments: --type, --version, --source')
+            print('Please provide all the arguments: --type, --version, --path')
             exit(1)
         # check if the radar type is valid
         validate.validate(radarType, version_name)
@@ -63,7 +67,7 @@ def arg_parser():
         zipped_file_path = os.path.join(temp_dir, version_name + '.zip')
 
         # print('version_dir_to_upload: ', version_dir_to_upload)
-        # print('zipped_file_path: ', zipped_file_path)
+        print('zipped_file_path: ', zipped_file_path)
         
         create_zip.create_zip(zipped_file_path, version_name)
         push_software.push_software(zipped_file_path, radarType, version_name)
